@@ -123,6 +123,29 @@ class Curve(object):
             
         return Curve(sig)
 
+    def __getstate__(self):
+        """
+        State of the object for serialization.
+
+        :return: (self.x, self.y)
+        """
+        return self.x, self.y
+
+    def __setstate__(self, state):
+        """
+        Set the state of the object from (x, y).
+
+        :param state: (x, y)
+        :return: None
+        """
+        self.x, self.y = state
+
+    def __eq__(self, other):
+
+        return isinstance(other, Curve) and (
+            all(other.x == self.x) and all(other.y == self.y)
+        )
+
     # @property
     # def x(self):
     #     return self.data[0]
@@ -788,8 +811,11 @@ class Curve(object):
         :param taps: Specifies the LFSR taps in decreasing order (Only 2 taps implemented).
         :returns: List of correct/incorrect values (0 is correct).
         """
-        output = [data[i] ^ (data[i + (taps[0] - taps[1])] ^ data[i + taps[0]])
-                  for i in range(0, len(data) - taps[0])]
+        output = [
+            (data[i] ^ (data[i + (taps[0] - taps[1])] ^ data[i + taps[0]])) or
+            not any(data[i:i+7])
+            for i in range(0, len(data) - taps[0])
+        ]
         return output
 
     def eye_box(self, start, f0, threshold=0.0, phase_step=0.05):
